ChiantiPy.Gui.gui_cl package — ChiantiPy 0.15.0 documentation

# ChiantiPy.Gui.gui_cl package

## Submodules

## ChiantiPy.Gui.gui_cl.gui module

Command line selection dialogs.

class `ChiantiPy.Gui.gui_cl.gui.` `choice2Dialog`(items, label=None, parent=None)

  Bases: `object`

  Make a single or multiplee selection from a list of items and another single or multiple selection from the same list.

  Useful for picking numerators and denominators.

  expects the input of an array of items, will select one or more from both widgets the keywords label and parent are there for consistency with real gui dialogs

`ChiantiPy.Gui.gui_cl.gui.` `chpicker`(path, filter='*.*', label=None)

  Select a filename from using a command line dialog.

  the label keyword is included for consistency but does nothing

class `ChiantiPy.Gui.gui_cl.gui.` `selectorDialog`(items, label=None, parent=None, multiChoice=False)

  Bases: `object`

  Make a single or multiple selection from a list of items.

  expects the input of an array of items, will select one or more the label and parent keywords are for consistency with other modules but do nothing

## Module contents

command-line selection dialogs